Top

    The Stranger Among Us
    Boston, Massachusetts
    January 5th 2002
    Kevin Scribner

    "tzimisce - go: counterspell deck"

    Crypt (12 cards, min=19, max=35, avg=6.83)
    ------------------------------------------
    2x Caliban			    6	ANI AUS VIC			    Tzimisce:2
    1x Lambach			    10	ANI AUS DOM VIC pre	cardinal    Tzimisce:2
    1x Stravinsky			    9	ANI AUS VIC pot		archbishop  Tzimisce:2
    1x Anton			    8	ANI AUS cel obf vic		    Tzimisce:2
    1x Little Tailor of Prague	    8	ANI AUS VIC dem			    Tzimisce:2
    1x Meshenka			    8	ANI AUS VIC		priscus	    Tzimisce:2
    1x Sascha Vykos, The Angel of Caine 8	AUS THA VIC ani dom	priscus	    Tzimisce:2
    1x Corine Marcón		    6	AUS VIC ani			    Tzimisce:2
    1x Devin Bisley			    5	ANI AUS vic			    Tzimisce:2
    1x Lolita Houston		    4	VIC aus				    Tzimisce:2
    1x Terrence			    4	ani aus vic			    Tzimisce:2

    library [90]:
    master cards [16]:
    2 anarch revolt
    6 blood doll
    1 library hunting ground
    1 powerbase: montreal
    1 the rack
    3 rötschreck
    2 smiling jack, the anarch
    action cards [6]:
    3 tier of souls
    3 revelations
    retainer cards [2]:
    2 revenant
    equipment cards [2]:
    1 ivory bow
    1 femur of toomler
    reaction cards [40]:
    6 cat's guidance
    6 forced awakening
    6 read the winds
    6 eagle's sight
    4 enhanced senses
    3 spirit's touch
    3 precognition
    6 telepzthic misdirection
    combat cards [24]:
    8 inner essence
    10 chiropteran marauder
    6 breath of the dragon

    notes:

    -- special thanks to jay kristoff, for his deck on thelasombra's site,
    which was the inspiration for this one, and to david d'avila-anderson,
    for his incredible articles on the subject of intercept-combat decks...
    -- i've been playing this deck for over a year now, in various forms,
    but it wasn't until bloodlines and 'read the winds' that i was able to
    really get it off the ground... the raw power and efficiency of that
    one card opened up so many card slots, which i was able to dedicate to
    forward pressure, without compromising my ability to fend off 4-on-1
    onslaughts turn after turn...
    -- in light of the lessons i learned at this tournament, i think i'll
    need to change the 2 anarch revolt to either 2 more smiling jack, or 2
    war ghoul... the anarch revolts organize the table against me too much,
    and turn my cross-table buddies into enemies... with smiling jack, they
    at least think twice before coming at me... removing 2 revolts also
    allows me to drop 2 of the eagle's sight, so maybe i'd go with 3 smiling
    jack, 3 war ghoul, and exchange the femur of toomler for one more
    revenant...
    -- i'm seriously considering swapping out the duplicate caliban in the
    crypt for either goratrix, matteus, omaya, or [most likely] jost
    werner... the duplicate crypt draw doesn't really hurt me much, but
    having jost's inherent stealth might make a big difference in some
    games...